# Read pre-processed gene summary values from file
# To use sample test data included in the TIN package as input:
gs <- readGeneSummaries(useToyData=TRUE)
# To use your own data, provide path to txt file with expression values:
# gs <- readGeneSummaries("/tmp/path/to/GeneLevelExpressionValues.txt")
Run the code above in your browser using DataLab