ChooseFileActionForm

Qualified name: tin.apps.assignments.forms.ChooseFileActionForm

class ChooseFileActionForm(*args, **kwargs)[source]

Bases: Form

A form to choose a file action.

Warning

This will allow a user to modify any file action, including file actions that are added to a course the user is not a teacher in.

This form is primarily intended for use with Javascript, where the file action id cannot be determined at template rendering time.

Form fields:

Methods

Attributes

media

Return all media required to render the widgets on this form.

__init__(*args, **kwargs)[source]
property media

Return all media required to render the widgets on this form.