FileActionForm

Qualified name: tin.apps.assignments.forms.FileActionForm

class FileActionForm(data=None, files=None, auto_id='id_%s', prefix=None, initial=None, error_class=<class 'django.forms.utils.ErrorList'>, label_suffix=None, empty_permitted=False, instance=None, use_required_attribute=None, renderer=None)[source]

Bases: ModelForm

A form to create (or edit) a FileAction.

Form fields:

Methods

clean

Hook for doing any extra form-wide cleaning after Field.clean() has been called on every field.

Attributes

media

Return all media required to render the widgets on this form.

clean()[source]

Hook for doing any extra form-wide cleaning after Field.clean() has been called on every field. Any ValidationError raised by this method will not be associated with a particular field; it will have a special-case association with the field named ‘__all__’.

property media

Return all media required to render the widgets on this form.